@@ -30,17 +30,17 @@ extern "C" {
 #define MagickLibVersion  0x710
 #define MagickLibVersionText  "7.1.0"
 #define MagickLibVersionNumber  10,0,0
-#define MagickLibAddendum  "-50 beta"
+#define MagickLibAddendum  "-52"
 #define MagickLibInterface  10
 #define MagickLibMinInterface  10
 #define MagickPlatform  "armv7l"
 #define MagickppLibVersionText  "7.1.0"
 #define MagickppLibVersionNumber  5:0:0
-#define MagickppLibAddendum  "-50 beta"
+#define MagickppLibAddendum  "-52"
 #define MagickppLibInterface  5
 #define MagickppLibMinInterface  5
-#define MagickGitRevision  "20489"
-#define MagickReleaseDate  "2022-10-08"
+#define MagickGitRevision  "20549"
+#define MagickReleaseDate  "2022-11-06"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
 #define MagickAuthoritativeURL  "https://imagemagick.org"
